@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2009 Bertjan Broeksema <broeksema@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mboxbenchmark.h"
@@ -49,6 +36,7 @@ void MBoxBenchmark::initTestCase()
 void MBoxBenchmark::cleanupTestCase()
 {
     mTempDir->remove();
+    delete mTempDir;
 }
 
 void MBoxBenchmark::testNoLockPerformance()
@@ -70,7 +58,8 @@ void MBoxBenchmark::testNoLockPerformance()
         mbox2.load(fileName());
         const auto lst = mbox2.entries();
         for (const MBoxEntry &entry : lst) {
-            mbox2.readMessage(entry);
+            auto mail = mbox2.readMessage(entry);
+            delete mail;
         }
     }
 }
@@ -98,7 +87,8 @@ void MBoxBenchmark::testProcfileLockPerformance()
 
         const auto lst = mbox2.entries();
         for (const MBoxEntry &entry : lst) {
-            mbox2.readMessage(entry);
+            auto mail = mbox2.readMessage(entry);
+            delete mail;
         }
     }
 }
