@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
-  Copyright (c) 2009 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
+  SPDX-FileCopyrightText: 2009 Bertjan Broeksema <broeksema@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
   NOTE: Most of the code inside here is an slightly adjusted version of
   kdepim/kmail/kmfoldermbox.cpp. This is why I added a line for Stefan Taferner.
@@ -311,7 +298,7 @@ static bool lessThanByOffset(const MBoxEntry &left, const MBoxEntry &right)
     return left.messageOffset() < right.messageOffset();
 }
 
-bool MBox::purge(const MBoxEntry::List &deletedEntries, QList<MBoxEntry::Pair> *movedEntries)
+bool MBox::purge(const MBoxEntry::List &deletedEntries, QVector<MBoxEntry::Pair> *movedEntries)
 {
     if (d->mMboxFile.fileName().isEmpty() || d->mReadOnly) {
         return false; // No file loaded yet or it's readOnly
@@ -348,7 +335,7 @@ bool MBox::purge(const MBoxEntry::List &deletedEntries, QList<MBoxEntry::Pair> *
     quint64 writeOffset = 0;
     bool writeOffSetInitialized = false;
     MBoxEntry::List resultingEntryList;
-    QList<MBoxEntry::Pair> tmpMovedEntries;
+    QVector<MBoxEntry::Pair> tmpMovedEntries;
 
     quint64 origFileSize = d->mMboxFile.size();
 
